import React, { ChangeEvent, useState } from "react";
import ReactPlayer from "react-player";
import { getAddress } from "../../common/lib/util";
import { ApplicationPayloadType, ApplicationStatus } from "../../common/types";
import Avatar from "../Avatar";
import ApplicationActions from "./ApplicationActions";

type OwnProps = {
  application: ApplicationPayloadType;
  selectedStatus: ApplicationStatus;
  status?: ApplicationStatus;
  onChangeStatus: (e: ChangeEvent<HTMLSelectElement>) => void;
  onUpdateStatus: (update?: any) => void;
};

const Applicant = ({
  application,
  status,
  onChangeStatus,
  onUpdateStatus,
  selectedStatus,
}: OwnProps) => {
  const [showDateTime, setShowDateTime] = useState<boolean>(false);
  const [dateTime, setDateTime] = useState<
    { date: string; time: string } | any
  >(null);
  const { candidate, score } = application;
  const renderMatches = (match: string, index: number) => (
    <p key={index}>{match}</p>
  );

  const onChangeDateTime = (e: ChangeEvent<HTMLInputElement>) => {
    setDateTime({ ...dateTime, [e.target.name]: e.target.value });
  };

  const onChangeAppicantStatus = (e: ChangeEvent<HTMLSelectElement>) => {
    if (e.target.value === "In progress") {
      setShowDateTime(true);
    } else {
      setShowDateTime(false);
    }

    onChangeStatus(e);
  };

  const onUpdateApplication = () => {
    if (selectedStatus === "In progress") {
      if (dateTime) {
        onUpdateStatus({
          interview: { ...application.interview, ...dateTime },
        });
      }
    } else {
      onUpdateStatus();
    }
  };

  console.log(application._id);

  return (
    <>
      <div className="mb-3 row">
        <div className="col-sm-3  ">
          <Avatar
            name={candidate?.name}
            url={candidate?.profilePicture}
            size="lg"
          />
        </div>
        <div className="col-sm-9">
          <div className="mb-3 row">
            <label className="col-sm-3">Name</label>
            <div className="col-sm-9">
              <p>
                <strong>{candidate.name}</strong>
              </p>
            </div>
          </div>
          <div className="row">
            <label className="col-sm-3 col-form-label">Resume</label>
            <div className="col-sm-9">
              <a
                className="btn btn-secondary btn-sm"
                href={candidate.resume}
                target="_blank"
                rel="noreferrer"
              >
                Preview
              </a>
            </div>
          </div>
        </div>
      </div>

      <div className="mb-3 row">
        <div className="col-sm-6">
          <div className="row">
            <label className="col-sm-4 col-form-label">Address</label>
            <div className="col-sm-8">
              <textarea
                className="form-control"
                rows={3}
                value={getAddress(candidate.contacts?.address)}
                disabled
              />
            </div>
          </div>
        </div>
        <div className="col-sm-6">
          <div className="row">
            <label className="col-sm-3 col-form-label">Phone</label>
            <div className="col-sm-9">
              <input
                type="text"
                className="form-control"
                name="phone"
                value={candidate.contacts?.phone || ""}
                disabled
              />
            </div>
          </div>
        </div>
      </div>
      <ReactPlayer
        url={candidate.selfIntro}
        controls
        width="100%"
        height="100%"
      />
      <hr />
      <table className="table table-hover table-sm">
        <thead>
          <tr>
            <th scope="col">Primary Score</th>
            <th scope="col">Secondary Score</th>
            <th scope="col">Similarity</th>
            <th scope="col">Total score</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td>{score.primary}</td>
            <td>{score.secondary}</td>
            <td>{score.similarity}</td>
            <td>{score.total}</td>
          </tr>
        </tbody>
      </table>
      <label className="mb-2">
        <strong>Primary match</strong>
      </label>
      <div className="matches">{score.primatyMatch?.map(renderMatches)}</div>
      <label className="mt-3">
        <strong>Secondary match</strong>
      </label>
      <div className="matches">{score.secondaryMatch?.map(renderMatches)}</div>
      <hr />

      {showDateTime && (
        <div className="row mb-3">
          <div className="col-md-6">
            <div className="row">
              <div className="col-md-6">
                <label className="form-label">Date</label>
                <input
                  type="date"
                  className="form-control"
                  name="date"
                  onChange={onChangeDateTime}
                />
              </div>
              <div className="col-md-6">
                <label className="form-label">Time</label>
                <input
                  type="time"
                  className="form-control"
                  name="time"
                  onChange={onChangeDateTime}
                />
              </div>
            </div>
          </div>
        </div>
      )}
      <ApplicationActions
        status={status}
        onChangeStatus={onChangeAppicantStatus}
        onUpdateStatus={onUpdateApplication}
        visible={status === "Pending" || status === "Rejected"}
      />
    </>
  );
};

export default Applicant;
