import React, { ChangeEvent } from "react";
import { ApplicationStatus } from "../../common/types";

type OwnProps = {
  status?: string;
  onChangeStatus: (e: ChangeEvent<HTMLSelectElement>) => void;
  onUpdateStatus: () => void;
  visible?: boolean;
};

const getStatusValues = (
  status?: string
): { label: string; value: ApplicationStatus }[] => {
  if (status === "Pending" || status === "Rejected") {
    return [
      { label: "Schedule", value: "In progress" },
      { label: "Reject", value: "Rejected" },
    ];
  } else if (status === "In progress") {
    return [
      { label: "Analyse", value: "Analyse" },
      { label: "Reject", value: "Rejected" },
    ];
  } else if (status === "Analyse") {
    return [
      { label: "Accept", value: "Accepted" },
      { label: "Reject", value: "Rejected" },
    ];
  } else {
    return [];
  }
};

const ApplicationActions = ({
  status,
  onChangeStatus,
  onUpdateStatus,
  visible = false,
}: OwnProps) => {
  const statusValues = getStatusValues(status);

  if (!visible) return null;

  const renderOptions = (
    { label, value }: { label: string; value: ApplicationStatus },
    index: number
  ) => (
    <option key={index} value={value}>
      {label}
    </option>
  );

  const onClickUpdate = () => onUpdateStatus();

  return (
    <div className="row ">
      <label className="col-sm-2 col-form-label">Status</label>
      <div className="col-sm-6 ">
        <div className="input-group ">
          <select
            className="form-select"
            id="inputGroupSelect04"
            aria-label="Example select with button addon"
            onChange={onChangeStatus}
          >
            <option value="select">Select</option>
            {statusValues.map(renderOptions)}
          </select>
          <button
            className="btn btn-primary "
            type="button"
            onClick={onClickUpdate}
          >
            Update & Next
          </button>
        </div>
      </div>
    </div>
  );
};

export default ApplicationActions;
