import React, { useState, useEffect, ChangeEvent } from "react";
import {
  useNavigate,
  useOutletContext,
  useSearchParams,
} from "react-router-dom";

import {
  ApplicationPayloadType,
  ApplicationStatus,
  JobPayloadType,
} from "../common/types";
import TabNavBar from "../components/TabNavBar";
import { useDispatch } from "react-redux";
import { updateApplicationAction } from "../common/actions/application";
import Applicant from "../components/Application/Applicant";
import Analyse from "../components/Application/Analyse";
import Interview from "../components/Application/Interview";

//Status map - Pending [Candidate tab] -> In progress [Interview tab] -> Analyse [Analyse tab] -> Accepted | Rejected

const Application = () => {
  const dispatch = useDispatch();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const [selectedTab, setSelectedTab] = useState("Candidate");
  const job = useOutletContext<JobPayloadType>();
  const applicationId = searchParams.get("applicationId");
  const application = (job.applications as ApplicationPayloadType[])?.find(
    (_application) => _application._id === applicationId
  );
  const [status, setStatus] = useState<ApplicationStatus>("Pending");

  useEffect(() => {
    if (application) {
      if (application?.status === "Pending") {
        setSelectedTab("Candidate");
      } else if (application?.status === "In progress") {
        setSelectedTab("Interview");
      } else if (application?.status === "Analyse") {
        setSelectedTab("Analyse");
      }
      setStatus(application.status);
    }
  }, [application]);

  if (!application) return null;

  const onUpdateStatus = (update?: any) => {
    dispatch(
      updateApplicationAction(
        {
          applicationId: application._id,
          update: { status, ...update },
        },
        () => {
          if (status === "Accepted" || status === "Rejected") {
            navigate(`/applications?jobId=${application.job}`);
          }
        }
      )
    );
  };

  const onChangeStatus = (e: ChangeEvent<HTMLSelectElement>) => {
    if (e.target.value !== "select") {
      setStatus(e.target.value as ApplicationStatus);
    }
  };

  return (
    <div className="card p-4">
      <TabNavBar
        selected={selectedTab}
        onSelect={setSelectedTab}
        selectedStatus={application.status}
      />
      {selectedTab === "Candidate" && (
        <Applicant
          application={application}
          status={application.status}
          onChangeStatus={onChangeStatus}
          onUpdateStatus={onUpdateStatus}
          selectedStatus={status}
        />
      )}
      {selectedTab === "Interview" && (
        <Interview
          status={application.status}
          onChangeStatus={onChangeStatus}
          onUpdateStatus={onUpdateStatus}
          application={application}
        />
      )}
      {selectedTab === "Analyse" && (
        <Analyse
          application={application}
          status={application.status}
          onChangeStatus={onChangeStatus}
          onUpdateStatus={onUpdateStatus}
        />
      )}
    </div>
  );
};

export default Application;
